@@ -10,6 +10,9 @@
  * Copyright 2003 Open Circuit Design, Inc., for MultiGiG Ltd.
  */
 
+#ifndef _MAGIC__GRAPHICS__GRTKINT_H
+#define _MAGIC__GRAPHICS__GRTKINT_H
+
 #include "utils/magic.h"
 
 /* Constants
@@ -58,6 +61,7 @@ extern GR_DISPLAY grDisplay;
 extern GC grGCFill, grGCText, grGCDraw, grGCCopy, grGCGlyph;
 
 extern bool grtkGetCursorPos();
+extern bool grtkGetCursorRootPos();
 extern bool grtkDrawGrid();
 extern void GrTkEnableTablet();
 extern void GrTkDisableTablet();
@@ -65,7 +69,7 @@ extern void GrTkSetCMap();
 extern void grtkPutText();
 extern void grtkFontText();
 extern void GrTkSetCursor();
-extern void GrTkTextSize();
+extern int  GrTkTextSize();
 extern void GrTkDrawGlyph();
 extern void GrTkBitBlt();
 extern void NullBitBlt();
@@ -76,9 +80,7 @@ extern void grtkSetCharSize();
 extern void grtkSetWMandC();
 extern void grtkFillRect();
 extern void grtkRectConvert();
-#ifdef NONMANHATTAN
 extern void grtkFillPolygon();
-#endif
 
 extern void grtkDrawLines();
 extern XSegment grtkLines[];
@@ -91,3 +93,4 @@ extern int grtkNbRects;
 #define GR_TK_FLUSH_RECTS() {if (grtkNbRects>0) {grtkFillRects(grtkRects, grtkNbRects); grtkNbRects=0;}}
 #define	GR_TK_FLUSH_BATCH() {GR_TK_FLUSH_LINES(); GR_TK_FLUSH_RECTS();}
 
+#endif /* _MAGIC__GRAPHICS__GRTKINT_H */
