@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header$";
+static const char rcsid[] __attribute__ ((unused)) = "$Header$";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -52,42 +52,42 @@ int WireWidth;			/* Thickness of material to use for wiring. */
 int WireLastDir;		/* Last direction in which a wire was run. */
 
 /* The following variable is used to communicate the desired root cellDef
- * between wireFindRootUse and wireFindRootFunc.
+ * between wireFindRootWindow and wireFindRootFunc.
  */
 
 static CellDef *wireDesiredDef;
 
 /*
  * ----------------------------------------------------------------------------
- *	wireFindRootUse --
+ *	wireFindRootWindow --
  *
  * 	This is a utility procedure to find a window containing a particular
  *	definition as its root.
  *
  * Results:
- *	The return value is the root use of a window, such that the
- *	use is an instance of rootDef.  If the definition isn't the
- *	root of any window then NULL is returned.
+ *	The return value is a pointer to a window for which the
+ *	window is an instance of rootDef.  If no window is an instance
+ *	of rootDef, then NULL is returned.
  *
  * Side effects:
  *	None.
  * ----------------------------------------------------------------------------
  */
 
-CellUse *
-wireFindRootUse(rootDef)
-    CellDef *rootDef;		/* Root definition for which a root use
+MagWindow *
+wireFindRootWindow(
+    CellDef *rootDef)		/* Root definition for which a root use
 				 * is desired.
 				 */
 {
-    CellUse *result;
-    extern int wireFindRootFunc();
+    MagWindow *mw;
+    extern int wireFindRootFunc(MagWindow *window, ClientData cdata); /* forward declaration cb_windows_search_t (MagWindow **) */
 
-    result = NULL;
+    mw = NULL;
     wireDesiredDef = rootDef;
     (void) WindSearch(DBWclientID, (ClientData) NULL, (Rect *) NULL,
-	    wireFindRootFunc, (ClientData) &result);
-    return result;
+	    wireFindRootFunc, PTR2CD(&mw));
+    return mw;
 }
 
 /* The following search function is called for each window.  If the
@@ -95,16 +95,18 @@ wireFindRootUse(rootDef)
  * with the window's root cellUse (and the search is aborted).
  */
 
+/* @typedef cb_windows_search_t */
 int
-wireFindRootFunc(window, cellUsePtr)
-    MagWindow *window;			/* A layout window. */
-    CellUse **cellUsePtr;		/* Pointer to cellUse pointer. */
+wireFindRootFunc(
+    MagWindow *window,		/* A layout window. */
+    ClientData cdata)		/* Copy layout window pointer to this */
 {
+    MagWindow **mwPtr = (MagWindow **)CD2PTR(cdata);
     CellUse *use;
 
     use = (CellUse *) window->w_surfaceID;
     if (use->cu_def != wireDesiredDef) return 0;
-    *cellUsePtr = use;
+    *mwPtr = window;
     return 1;
 }
 
@@ -128,12 +130,15 @@ wireFindRootFunc(window, cellUsePtr)
  */
 
 void
-WirePickType(type, width)
-    TileType type;		/* New type of material to use for wiring.
+WirePickType(
+    TileType type,		/* New type of material to use for wiring.
 				 * If less than zero, then pick a new type
 				 * based on what's underneath the cursor.
 				 */
-    int width;			/* Width to use for future wiring.  If type
+    const Point *ppoint,	/* If non-NULL, contains a point position
+				 * from which to get the wire type.
+				 */
+    int width)			/* Width to use for future wiring.  If type
 				 * is less than zero then this parameter is
 				 * ignored and the width of the material
 				 * underneath the cursor is used.
@@ -162,12 +167,25 @@ WirePickType(type, width)
      * so each type gets a chance.
      */
 
-    w = ToolGetPoint(&point, &scx.scx_area);
-    if (w == NULL)
+    if (ppoint)
     {
-	TxError("Can't use cursor to select wiring material unless\n");
-	TxError("    cursor is in a layout window.\n");
-	return;
+	point.p_x = ppoint->p_x;
+	point.p_y = ppoint->p_y;
+	w = wireFindRootWindow(EditRootDef);
+	scx.scx_area.r_xbot = point.p_x;
+	scx.scx_area.r_ybot = point.p_y;
+	scx.scx_area.r_xtop = scx.scx_area.r_xbot + 1;
+	scx.scx_area.r_ytop = scx.scx_area.r_ybot + 1;
+    }
+    else
+    {
+	w = ToolGetPoint(&point, &scx.scx_area);
+	if (w == NULL)
+	{
+	    TxError("Can't use cursor to select wiring material unless\n");
+	    TxError("    cursor is in a layout window.\n");
+	    return;
+	}
     }
     scx.scx_use = (CellUse *) w->w_surfaceID;
     scx.scx_trans = GeoIdentityTransform;
@@ -253,13 +271,13 @@ WirePickType(type, width)
  */
 
 int
-WireGetWidth()
+WireGetWidth(void)
 {
     return WireWidth;
 }
 
 TileType
-WireGetType()
+WireGetType(void)
 {
     return WireType;
 }
@@ -283,22 +301,23 @@ WireGetType()
  */
 
 void
-WireAddLeg(rect, point, direction)
-    Rect *rect;			/* Describes the current (last-painted) leg
+WireAddLeg(
+    Rect *rect,			/* Describes the current (last-painted) leg
 				 * of the wire, in root coordinates.  If NULL,
 				 * then the box is used for this.
 				 */
-    Point *point;		/* Describes where to paint the wire to, in
+    const Point *point,		/* Describes where to paint the wire to, in
 				 * root coordinates.  If NULL, then the cursor
 				 * location is used as the point.
 				 */
-    int direction;		/* Which direction to run the wire, in root
+    int direction)		/* Which direction to run the wire, in root
 				 * coords.  If WIRE_CHOOSE, then pick a
 				 * direction based on point.  If WIRE_VERTICAL
 				 * or WIRE_HORIZONTAL, then run the wire in
 				 * the indicated direction.
 				 */
 {
+    MagWindow *w;
     Rect current, new, leg, editArea;
     CellDef *boxRootDef;
     SearchContext scx;
@@ -476,7 +495,8 @@ WireAddLeg(rect, point, direction)
      * windows.
      */
 
-    scx.scx_use = wireFindRootUse(EditRootDef);
+    w = wireFindRootWindow(EditRootDef);
+    scx.scx_use = w->w_surfaceID;
     if (scx.scx_use != NULL)
     {
 	SelectClear();
@@ -539,7 +559,7 @@ WireAddLeg(rect, point, direction)
  */
 
 void
-WireShowLeg()
+WireShowLeg(void)
 {
     Rect current, new, leg, editArea, *rect = &current;
     CellDef *boxRootDef;
@@ -713,18 +733,19 @@ WireShowLeg()
 #define WIRING_CONTACT_DOWN	0
 
 void
-WireAddContact(newType, newWidth)
-    TileType newType;		/* New type of material to use for wiring.
+WireAddContact(
+    TileType newType,		/* New type of material to use for wiring.
 				 * If less than zero, pick a new type based
 				 * on what's underneath the cursor.
 				 */
-    int newWidth;		/* New width to use for future wiring.  If
+    int newWidth)		/* New width to use for future wiring.  If
 				 * newType is less than zero, then this
 				 * parameter is ignored and the width of
 				 * the material underneath the cursor is
 				 * used.
 				 */
 {
+    MagWindow *w;
     Rect oldLeg, contactArea, tmp, tmp2, editArea;
     CellDef *boxRootDef;
     TileType oldType;
@@ -760,7 +781,7 @@ WireAddContact(newType, newWidth)
      * there's no need to add a contact.
      */
 
-    WirePickType(newType, newWidth);
+    WirePickType(newType, (Point *)NULL, newWidth);
     if (WireType == oldType)
     {
 	TxError("The new wiring layer is the same as the old one, so\n");
@@ -1001,7 +1022,8 @@ WireAddContact(newType, newWidth)
      */
 
     SelectClear();
-    scx.scx_use = wireFindRootUse(EditRootDef);
+    w = wireFindRootWindow(EditRootDef);
+    scx.scx_use = w->w_surfaceID;
     if (scx.scx_use != NULL)
     {
 	scx.scx_trans = GeoIdentityTransform;
@@ -1050,10 +1072,11 @@ WireAddContact(newType, newWidth)
  * ----------------------------------------------------------------------------
  */
 
+/** @typedef cb_database_buttonhandler_t */
 void
-WireButtonProc(w, cmd)
-    MagWindow *w;			/* Window in which button was pushed. */
-    TxCommand *cmd;		/* Describes exactly what happened. */
+WireButtonProc(
+    MagWindow *w,		/* Window in which button was pushed. */
+    TxCommand *cmd)		/* Describes exactly what happened. */
 {
     /* We do commands on the down-pushes and ignore the releases. */
 
@@ -1063,7 +1086,7 @@ WireButtonProc(w, cmd)
     switch (cmd->tx_button)
     {
 	case TX_LEFT_BUTTON:
-	    WirePickType(-1, 0);
+	    WirePickType(-1, (Point *)NULL, 0);
 	    break;
 	case TX_RIGHT_BUTTON:
 	    WireAddLeg((Rect *) NULL, (Point *) NULL, WIRE_CHOOSE);
@@ -1092,9 +1115,9 @@ WireButtonProc(w, cmd)
  */
 
 void
-WireInit()
+WireInit(void)
 {
-    static char *doc =
+    static const char *doc =
 "You are currently using the \"wiring\" tool.  The button actions are:\n\
    left    - pick a wiring layer and width (same as \":wire type\")\n\
    right   - add a leg to the wire (same as \":wire leg\")\n\
